@@ -24,8 +24,6 @@ class Domoticz(IPlugin):
 		self._ = translation = gettext.translation(domain='domoticz',
 			localedir=self.path,
                         languages=[self.configuration_lisa['lang']]).ugettext
-#
-#
 #
 	
 	def switchlight(self, jsonInput):
@@ -42,7 +40,7 @@ class Domoticz(IPlugin):
 #
 		idex= location + "_" + on_off
 #		#log.msg("WAMP session data received (transport ID %s): %s" % (self._parent._transportid, payload))
-		log.msg("index :  %s" % (idex)		
+		log.msg("index :  %s" % (idex))		
 #		for rs in self.configuration_plugin['param_dz']
 #			if rs['ids'] == idex
 #				bodies == rs['boy']
